@@ -1,4 +1,5 @@
 import asyncio
+import atexit
 import logging
 import logging.handlers
 import time
@@ -55,6 +56,8 @@ def wrap_logging_handler(
         ), no_return=True, statistic_name="logger",
     )
 
+    atexit.register(handler.flush)
+
     return buffered_handler
 
 
