@@ -1,8 +1,8 @@
 from .base import Service, ServiceMeta, SimpleServer
 from .process import ProcessService, RespawningProcessService
 from .profiler import Profiler
-from .tcp import TCPServer
-from .tls import TLSServer
+from .tcp import RobustTCPClient, TCPClient, TCPServer
+from .tls import RobustTLSClient, TLSClient, TLSServer
 from .tracer import MemoryTracer
 from .udp import UDPServer
 
@@ -12,10 +12,14 @@ __all__ = (
     "ProcessService",
     "Profiler",
     "RespawningProcessService",
+    "RobustTCPClient",
+    "RobustTLSClient",
     "Service",
     "ServiceMeta",
     "SimpleServer",
+    "TCPClient",
     "TCPServer",
+    "TLSClient",
     "TLSServer",
     "UDPServer",
 )
